@@ -10,7 +10,8 @@ if [ $# != 1 ] ; then
 	echo install-post.sh vserver
 else
 	VROOT=/vservers/$1
-	rm -fr $VROOT/dev/*
+	rm -fr $VROOT/dev
+	mkdir $VROOT/dev && chmod 755 $VROOT/dev
 	mkdir $VROOT/dev/pts
 	vserver_mknod $VROOT/dev/null c 1 3 666
 	vserver_mknod $VROOT/dev/zero c 1 5 666
@@ -21,7 +22,8 @@ else
 	vserver_mknod $VROOT/dev/ptmx c 5 2 666
 	test -f /etc/vservers/$1.conf || cp /usr/lib/vserver/sample.conf /etc/vservers/$1.conf
 	test -f /etc/vservers/$1.sh   || cp /usr/lib/vserver/sample.sh /etc/vservers/$1.sh
-
+	echo NETWORKING=yes >$VROOT/etc/sysconfig/network
+	echo HOSTNAME=$1 >>$VROOT/etc/sysconfig/network
 	(
 		cd $VROOT/etc/rc.d/init.d || cd $VROOT/etc/init.d
 		for serv in *
