@@ -3,6 +3,7 @@
 #include <errno.h>
 #include <string.h>
 #include <sys/stat.h>
+#include <sys/wait.h>
 #include <fcntl.h>
 #include <unistd.h>
 #include <utime.h>
@@ -179,6 +180,8 @@ void vutil_loadallpkg (string &refserver, list<PACKAGE> &packages)
 	ipfstream oo (cmd.c_str());
 	copy (istream_iterator<string>(oo),istream_iterator<string>()
 		,inserter(packages,packages.begin()));
+	int status;
+	wait (&status);
 }
 
 int vutil_lstat (string path, struct stat &st)
