@@ -8,7 +8,7 @@
 #include <string>
 #include <set>
 #include <algorithm>
-#include <iostream.h>
+#include <iostream>
 #include <pfstream.h>
 #include <list>
 
